package cz.iivos.pjj.weather;

import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.net.URL;
import java.util.Properties;

import javax.swing.Icon;
import javax.swing.ImageIcon;

/**
 * Objekt obsahující informaci o stavu počasí v jednom městě.
 */
public class WeatherBean implements Serializable {

    /**
     * Název města.
     */
    private String cityName;
    /**
     * Informace o teplotě ve městě.
     */
    private String temperature;
    /**
     * Informace o stavu počasí ve městě.
     */
    private String description;
    /**
     * Obrázek stavu počasí ve městě.
     */
    private Icon image;
    /**
     * Tabulka jmen obrázků pro názvy jednotlivých stavů počasí.
     */
    private static Properties imageNames;

    // statický blok - provede se při načtení třídy do paměti
    // typicky před prvním použitím třídy
    static {
        imageNames = new Properties();

        // načtení popisu počasí a názvů obrázků
        // ze souboru properties
        try {
            // získání URL souboru properties
            InputStream is =
                    WeatherBean.class.getResourceAsStream("/imagenames.properties");
            // načtení obsahu souboru properties
            imageNames.load(is);
            //imageNames.list(System.out);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * Vytvoří novou instanci třídy WeatherBean.
     *
     * @param city
     *            název města.
     * @param weatherDescription
     *            popis stavu počasí.
     * @param cityTemperature
     *            popis teploty.
     */
    public WeatherBean(String city, String weatherDescription,
            String cityTemperature) {
        cityName = city;
        temperature = cityTemperature;
        description = weatherDescription.trim();

        URL url =
                WeatherBean.class.getResource("/images/"
                + imageNames.getProperty(description,
                "noinfo.jpg"));
        image = new ImageIcon(url);
    }

    /**
     * Vrátí název města.
     *
     * @return název města.
     */
    public String getCityName() {
        return cityName;
    }

    /**
     * Vrátí teplotu ve městě.
     *
     * @return teplotu ve městě.
     */
    public String getTemperature() {
        return temperature;
    }

    /**
     * Vrátí stav počasí ve městě.
     *
     * @return stav počasí ve městě.
     */
    public String getDescription() {
        return description;
    }

    /**
     * Vrátí obrázek stavu počasí ve městě.
     *
     * @return obrázek stavu počasí ve městě.
     */
    public Icon getImage() {
        return image;
    }
}
