package cz.iivos.pjj.weather;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.JPanel;

public class WeatherItem extends JPanel {

	/**
	 * Data o počasí.
	 */
	private WeatherBean weatherBean;

	/**
	 * Obrázek na pozadí.
	 */
	private static ImageIcon backgroundImage;

	static {
		// získání URL obrázku pozadí
		URL url = WeatherItem.class.getResource("/images/back.jpg");

		// načtení obrázku pozadí
		backgroundImage = new ImageIcon(url);
	}

	/**
	 * Vytvoří novou instanci třídy WeatherItem.
	 * 
	 * @param bean
	 *            data počasí, které bude tato komponenta zobrazovat.
	 */
	public WeatherItem(WeatherBean bean) {
		weatherBean = bean;
	}

	@Override
	public void paintComponent(Graphics g) {
		super.paintComponent(g);

		// vykreslení pozadí
		backgroundImage.paintIcon(this, g, 0, 0);

		// nastavení fontu a vykreslení názvu města
		// a teploty
		Font font = new Font("SansSerif", Font.BOLD, 12);
		g.setFont(font);
		g.setColor(Color.WHITE);
		g.drawString(weatherBean.getCityName(), 10, 19);
		g.drawString(weatherBean.getTemperature(), 130, 19);

		// zobrazení obrázku počasí
		weatherBean.getImage().paintIcon(this, g, 253, 1);
	}

	@Override
	public Dimension getMinimumSize() {
		return getPreferredSize();
	}

	@Override
	public Dimension getPreferredSize() {
		return new Dimension(backgroundImage.getIconWidth(),
				backgroundImage.getIconHeight());
	}
}
