package cz.iivos.pjj.weather;

import java.awt.BorderLayout;
import java.rmi.ConnectException;
import java.rmi.Naming;
import java.util.List;
import javax.swing.JFrame;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ListModel;

/**
 * Komponenta uživatelského rozhraní zobrazující stav počasí ve
 * vybraných městech. Tato komponenta získává údaje ze serveru pomocí
 * rozhraní RMI.
 */
public class WeatherServiceClient extends JPanel {

	/**
	 * Vytvoří novou komponentu WeatherServiceClient, načte data ze
	 * serveru a inicializuje komponenty uživatelského rozhraní.
	 * 
	 * @param server
	 *            adresa serveru, odkud se načítají data.
	 */
	public WeatherServiceClient(String server) {
		try {
			// adresa vzdáleného objektu
			String remoteName =
					"rmi://" + server + "/WeatherService";
			// vyhledání vzdáleného objektu
			WeatherService weatherService =
					(WeatherService) Naming.lookup(remoteName);
			// získání informací o počasí
			List<WeatherBean> weatherInformation =
					weatherService.getWeatherInformation();
			// vytvoření modelu
			ListModel weatherListModel =
					new WeatherListModel(weatherInformation);
			// vytvoření komponenty gui
			JList weatherList = new JList(weatherListModel);
			weatherList.setCellRenderer(new WeatherCellRenderer());
			setLayout(new BorderLayout());
			add(new JScrollPane(weatherList));
		} catch (ConnectException e) {
			System.err.println("Spojení k serveru selhalo. "
					+ "Server může být dočasně nedostupný.");
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void main(String[] args) {
		WeatherServiceClient client = null;
		if (args.length == 0) {
			client = new WeatherServiceClient("localhost");
		} else {
			client = new WeatherServiceClient(args[0]);
		}

		JFrame frame = new JFrame("RMI Předpověď počasí");
		frame.add(client);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.pack();
		frame.setVisible(true);
	}
}
